Crate emojfuscate

Crate emojfuscate 

Structs

DecodeEmojiToBytes
This holds an iterator that produces bytes that are interpreted as UTF-8 encoded emoji
EncodeBytesAsEmoji
This is a representation of a stream of data that is being converted into emoji. Calling emojfuscate_stream on something

Enums

ByteInSequence
FromEmojiError

Traits

ConstructFromEmoji
A trait representing things that can be constructed from Emoji
Demojfuscate
Once you have something that can be constructed from emoji and a source of emoji then you can try to demojfuscate the data
Emojfuscate
A trait reprenting things that can be encoded as emoji, either as a lazy stream of bytes or strictly into a String.
EmojfuscateByteStream
This is the same thing as Emojfuscate but it only applies to Iterators of bytes, it’s an optimization to avoid u8 iterators wrapping each u8 into Once which happens with the default implementation of emojfuscate_stream
IsEmojiRepresentation
A trait representing some source of emoji data. This abstraction let’s us use both Strings and streams of bytes when demojfuscating data

Derive Macros

ConstructFromEmoji
Emojfuscate