pub trait Demojfuscate<A, I>{
// Required methods
fn demojfuscate_stream(self) -> DemojfuscateIterator<A, I>;
fn demojfuscate(self) -> Result<A, FromEmojiError>
where Self: Sized;
}Expand description
Once you have something that can be constructed from emoji and a source of emoji then you can try to demojfuscate the data