pub trait Emojfuscate<I>where
I: Iterator<Item = ByteInSequence>,{
// Required method
fn emojfuscate_stream(self) -> EncodeBytesAsEmoji<I> ⓘ;
// Provided method
fn emojfuscate(self) -> String
where Self: Sized { ... }
}Expand description
A trait reprenting things that can be encoded as emoji, either as a lazy stream of bytes or strictly into a String.
For the most part you shouldn’t need to make your own implementations of this. Most types in the standard library already has an implementation and implementations can be derived for your custom types using the derive macro.