pub struct EncodeBytesAsEmoji<I>where
I: Iterator<Item = ByteInSequence>,{ /* private fields */ }Expand description
This is a representation of a stream of data that is being converted into emoji. Calling
emojfuscate_stream on something
Implementations
Sourceimpl<I> EncodeBytesAsEmoji<I>where
I: Iterator<Item = ByteInSequence>,
impl<I> EncodeBytesAsEmoji<I>where
I: Iterator<Item = ByteInSequence>,
pub fn new(iter: I) -> Self
Sourcepub fn add_start_emoji(
self,
) -> EncodeBytesAsEmoji<Chain<Once<ByteInSequence>, I>> ⓘ
pub fn add_start_emoji( self, ) -> EncodeBytesAsEmoji<Chain<Once<ByteInSequence>, I>> ⓘ
When types have a size that is unknown at compile time it can be come ambiguous where one
ends and one starts. E.g. if the tuple ("hello","world") was just a series of bytes, how
could we tell it apart from ("helloworld","")?
This function along with add_stop_emoji adds special emoji that signify the start and stop of a sequence of data whose length is unknown at compile time.
pub fn add_stop_emoji( self, ) -> EncodeBytesAsEmoji<Chain<I, Once<ByteInSequence>>> ⓘ
Sourcepub fn chain_emoji_bytes<I2>(
self,
other: EncodeBytesAsEmoji<I2>,
) -> EncodeBytesAsEmoji<Chain<I, I2>> ⓘwhere
I2: Iterator<Item = ByteInSequence>,
pub fn chain_emoji_bytes<I2>(
self,
other: EncodeBytesAsEmoji<I2>,
) -> EncodeBytesAsEmoji<Chain<I, I2>> ⓘwhere
I2: Iterator<Item = ByteInSequence>,
This is used to combine multiple streams of emoji into one. E.g. the Emojfuscate
implementation for (A, B) for is just calling emojfuscate_stream on the two values in
the tuple and then combining them:
Sourcepub fn bypass_future_trait_implementation_compiler_error(
self,
) -> EncodeBytesAsEmoji<IteratorWrapper<I>> ⓘ
pub fn bypass_future_trait_implementation_compiler_error( self, ) -> EncodeBytesAsEmoji<IteratorWrapper<I>> ⓘ
Rust has a philosphy where adding a trait implementation is not supposed to be a breaking change. So to avoid breakage from crates adding trait implementations it considers concrete types from a crate to have a possible future implementation of all the traits from the same crate.
This means that you will get a compiler error if you make a trait implementation for all
generic values of I that implements some trait and then later on make an implementation
for a concrete type from the same crate. Because if that crate decided to make an
instance of that trait for that type in the future then there would be conflicting
implementations of your trait.
This happens in this crate because we want to say that all Iterators I implement Emojfuscate as long as the Item iterated over implements Emojfuscate. This should cause conflicts because the Iterator trait is from the standard library along with all the basic types such as u8, bool etc.
For some reason this problem doesn’t arise here. Except for tuples with two or three values (not four and up). But luckily we can make the compiler error go away by just wrapping the resuling iterator in useless IteratorWrapper layer 🧠